@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Lite.pm 353 2010-03-17 21:08:34Z kutterma $
+# $Id: Lite.pm 386 2011-08-18 19:48:31Z kutterma $
 #
 # ======================================================================
 
@@ -13,7 +13,7 @@ package XMLRPC::Lite;
 use SOAP::Lite;
 use strict;
 
-our $VERSION = 0.711;
+our $VERSION = 0.714;
 
 # ======================================================================
 
@@ -364,7 +364,7 @@ sub new {
         serializer => XMLRPC::Serializer->new,
         deserializer => XMLRPC::Deserializer->new,
         on_action => sub {return},
-        uri => 'http://unspecified/',
+        default_ns => 'http://unspecified/',
         @_
     );
 }
